@@ -101,7 +101,7 @@ set_options <- function(...) {
                             "` for package treePlotArea."))
             }
         }
-        res <- fritools_set_options(..., package_name = "treePlotArea",
+        res <- fritools::set_options(..., package_name = "treePlotArea",
                                      overwrite = TRUE)
     }
     return(invisible(res))
@@ -109,7 +109,7 @@ set_options <- function(...) {
 
 set_defaults <- function() {
   defaults <- get_defaults()
-  res <- fritools_set_options(defaults, package_name = "treePlotArea",
+  res <- fritools::set_options(defaults, package_name = "treePlotArea",
                                overwrite = FALSE)
   return(res)
 }
@@ -118,10 +118,10 @@ get_options <- function(type = c("angle_counts", "boundaries", "all")) {
     set_defaults()
     t <- match.arg(type)
     if (t == "all") {
-        res <- fritools_get_options(package_name = "treePlotArea",
+        res <- fritools::get_options(package_name = "treePlotArea",
                                      flatten_list = FALSE)
     } else {
-        res <- fritools_get_options(package_name = "treePlotArea",
+        res <- fritools::get_options(package_name = "treePlotArea",
                                      flatten_list = FALSE)[[t]]
     }
     return(res)
